@@ -11,4 +11,4 @@ class TravelperkExtension:
     gender: str = None
     date_of_birth: str = None
     travel_policy: str = None
-    country_or_residence: str = None
+    country_of_residence: str = None
